@@ -8,3 +8,7 @@
 
 /* Define to 1 if ANSI function prototypes are usable.  */
 #undef PROTOTYPES
+
+/* Define to 1 for better use of the debugging malloc library.  See 
+   site ftp.antaire.com in antaire/src, file dmalloc/dmalloc.tar.gz.  */
+#undef WITH_DMALLOC
